Stan Math Library: stan::math::array_builder< T > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Public Attributes | List of all members
stan::math::array_builder< T > Struct Template Reference

Structure for building up arrays in an expression (rather than in statements) using an argumentchaining add() method and a getter method array() to return the result. More...

`#include <array_builder.hpp>`

## Public Member Functions
| array_builder ()
template<typename F >
array_builder & | add (const F &u)
std::vector< T > | array ()

## Public Attributes
std::vector< T > | x_

## Detailed Description

### template<typename T>
struct stan::math::array_builder< T >

Structure for building up arrays in an expression (rather than in statements) using an argumentchaining add() method and a getter method array() to return the result.

Definition at line 16 of file array_builder.hpp.

## Constructor & Destructor Documentation

template<typename T >

stan::math::array_builder< T >::array_builder | ( |  | ) |
| inline

Definition at line 18 of file array_builder.hpp.

## Member Function Documentation

template<typename T >
template<typename F >

array_builder& stan::math::array_builder< T >::add | ( | const F & | u | ) |
| inline

Definition at line 20 of file array_builder.hpp.

template<typename T >

std::vector<T> stan::math::array_builder< T >::array | ( |  | ) |
| inline

Definition at line 26 of file array_builder.hpp.

## Member Data Documentation

template<typename T >

std::vector<T> stan::math::array_builder< T >::x_

Definition at line 17 of file array_builder.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/mat/fun/array_builder.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.